@@ -102,7 +102,7 @@ gda_vprovider_hub_get_type (void)
 	static GType type = 0;
 
 	if (G_UNLIKELY (type == 0)) {
-		static GStaticMutex registering = G_STATIC_MUTEX_INIT;
+		static GMutex registering;
 		if (type == 0) {
 			static GTypeInfo info = {
 				sizeof (GdaVproviderHubClass),
@@ -116,10 +116,10 @@ gda_vprovider_hub_get_type (void)
 				0
 			};
 			
-		g_static_mutex_lock (&registering);
+		g_mutex_lock (&registering);
 		if (type == 0)
 			type = g_type_register_static (GDA_TYPE_VPROVIDER_DATA_MODEL, "GdaVproviderHub", &info, 0);
-		g_static_mutex_unlock (&registering);
+		g_mutex_unlock (&registering);
 		}
 	}
 
